import type PO from 'pofile'

// module 'pofile' does not export its internal types
export type { PO }
export type POHeaders = PO['headers']
export type PODictionary = Record<string, string[]>
export type POItem = InstanceType<typeof PO.Item>

export const PROJECT_NAME = 'gettext'

export function itemKey (item: POItem, plural = true): string {
  return `${item.msgctxt || ''}\x00${item.msgid}\x01${(plural && item.msgid_plural) || ''}`
}

export class AmbiguousPluralFormException extends Error {
  readonly poItem: POItem
  readonly collidingPoItem: POItem

  constructor (poItem: POItem, collidingPoItem: POItem) {
    super()
    this.poItem = poItem
    this.collidingPoItem = collidingPoItem
    this.message = this.toString()
  }

  override toString () {
    return `
      Usage of singular and plural form of "${this.poItem.msgid}" in the same context:
      ${(this.collidingPoItem.msgctxt || '[no context]')}
      \n\nReferences:\n${this.poItem.references.join(', ')}\n
      \n${this.collidingPoItem.references.join(', ')}
      \n\nChange the context of at least one of the strings (pgettext) or use ngettext/npgettext in both cases.
    `
  }
}
