import { describe, it, expect } from '@jest/globals'
import { build } from 'vite'

import vitePluginOxManifests from '../../dist/index'
import { getFileFromBundle, getDirname } from '../util'

const __dirname = getDirname(import.meta.url)

describe('Preload helper separate', function () {
  it('replaces code for relative path loading', async function () {
    const bundle = await build({
      root: __dirname,
      logLevel: 'silent',
      build: {
        minify: false,
        write: false,
        rollupOptions: {
          input: {}
        }
      },
      plugins: [vitePluginOxManifests({
        entryPoints: [`${__dirname}/{foo,bar}.js`]
      })]
    })
    const preloadHelper = getFileFromBundle('preload', bundle)
    expect(preloadHelper.code).toContain('const __vitePreload = function preload')

    const manifestFile = getFileFromBundle('manifest', bundle)
    const manifests = JSON.parse(manifestFile.source)
    expect(Object.keys(manifests)).toHaveLength(4)
    expect(manifests['index.js'].imports).toHaveLength(1)
    expect(manifests['index.js'].imports[0]).toContain('preload-helper')
  })
})
